package com.jusfoun.ydylsz.controller;

import com.jusfoun.ydylsz.service.AlarmService;
import com.jusfoun.ydylsz.utils.StringUtils;
import com.jusfoun.ydylsz.vo.WarehouseEmptyAlarmVO;
import com.jusfoun.ydylsz.vo.WarehouseOverdueAlarmVO;
import com.jusfoun.ydylsz.vo.out.base.RootResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;


@RestController
@RequestMapping("/alarm")
@Api(description="报警")
public class AlarmController {

    @Autowired
    private AlarmService alarmService;

    @ApiOperation(value = "空仓报警(分页列表查询)", notes = "空仓报警(分页列表查询)")
    @GetMapping(value = "/emptyWarehouse/page")
    public RootResult<Object> emptyWarehousePageList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                     @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                                     @ApiParam(value = "处理状态 0:未处理 1:已处理",required = false) @RequestParam(value = "clzt", required = false) Integer clzt,
                                                     @ApiParam(value = "处理方式 0:手动 1:系统自动",required = false) @RequestParam(value = "clfs", required = false) Integer clfs,
                                                     @ApiParam(value = "仓房状态 1:空仓 2:半仓",required = false) @RequestParam(value = "cfzt", required = false) Integer cfzt,
                                                     @ApiParam(value = "承储企业名称",required = false) @RequestParam(value="ccqy",required = false) String ccqy,
                                                     @ApiParam(value = "仓房名称",required = false) @RequestParam(value="cfmc",required = false) String cfmc,
                                                     @ApiParam(value = "库区编码",required = false) @RequestParam(value = "kqbm",required = false ) String kqbm) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.getEmptyWarehousePageList(pageNum, pageSize,clzt,clfs,cfzt,ccqy,cfmc,kqbm));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "空仓报警处理", notes = "空仓报警处理")
    @PostMapping(value = "/emptyWarehouse/deal")
    public RootResult<Object> dealEmptyWarehouseAlarm(@RequestBody WarehouseEmptyAlarmVO vo) {
        RootResult<Object> r = new RootResult<>();
        try {

            if(StringUtils.isEmpty(vo.getId()) || StringUtils.isEmpty(vo.getClrid()) || StringUtils.isEmpty(vo.getClrmc()) || StringUtils.isEmpty(vo.getClyj())){
                r.setCode(500);
                r.setData("参数错误！");
            }
            vo.setClfs(0);//手动处理
            vo.setClsj(new Date());
            vo.setClzt(1);//已处理
            if(alarmService.dealEmptyWarehouseAlarm(vo)){
                r.setCode(200);
                r.setData("处理完成！");
            }else{
                r.setData("处理失败！");
            }

        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "存储超限告警(分页列表查询)", notes = "存储超限告警(分页列表查询)")
    @GetMapping(value = "/overdue/page")
    public RootResult<Object> overduePageList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                              @ApiParam(value = "处理状态 0:未处理 1:已处理",required = false) @RequestParam(value = "clzt",required = false) Integer clzt,
                                              @ApiParam(value = "承储企业名称",required = false) @RequestParam(value="ccqy",required = false) String ccqy,
                                              @ApiParam(value = "仓房名称",required = false) @RequestParam(value="cfmc",required = false) String cfmc,
                                              @ApiParam(value = "处理方式 0:手动 1:系统自动",required = false) @RequestParam(value = "clfs", required = false) Integer clfs,
                                              @ApiParam(value = "品种编码",required = false) @RequestParam(value = "pzbm", required = false) String pzbm,
                                              @ApiParam(value = "库区编码",required = false) @RequestParam(value = "kqbm", required = false) String kqbm
                                                     ) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.getOverdueWarehousePageList(pageNum, pageSize,clzt,ccqy,cfmc,pzbm,clfs,kqbm));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "存储超限告警处理", notes = "存储超限告警处理")
    @PostMapping(value = "/overdue/deal")
    public RootResult<Object> dealOverdueAlarm(@RequestBody WarehouseOverdueAlarmVO vo) {
        RootResult<Object> r = new RootResult<>();
        try {

            if(StringUtils.isEmpty(vo.getId()) || StringUtils.isEmpty(vo.getClrid()) || StringUtils.isEmpty(vo.getClrmc()) || StringUtils.isEmpty(vo.getClyj())){
                r.setCode(500);
                r.setData("参数错误！");
            }
            vo.setClfs(0);//手动处理
            vo.setClsj(new Date());
            vo.setClzt(1);//已处理
            if(alarmService.dealOverdueAlarm(vo)){
                r.setCode(200);
                r.setData("处理完成！");
            }else{
                r.setData("处理失败！");
            }

        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "首页预警数据统计", notes = "首页预警数据统计")
    @PostMapping(value = "/statistic")
    public RootResult<Object> statisticAlarm() {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.statisticAlarm());
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    /******************************以下是老接口***********************************/
    @ApiOperation(value = "库存超限告警(旧)", notes = "库存超限告警(旧)")
    @GetMapping(value = "/selectStorageOverrun")
    public RootResult<Object> selectStorageOverrun(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                                   @RequestParam(value="kqmc",required = false) String kqmc,
                                                   @RequestParam(value="type",required = true) String type) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.selectStorageOverrun(pageNum, pageSize,kqmc,type));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "空仓报警(旧)", notes = "空仓报警(旧)")
    @GetMapping(value = "/selectEmptyWarehouse")
    public RootResult<Object> selectEmptyWarehouse(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                                   @RequestParam(value="kqmc",required = false) String kqmc) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.selectEmptyWarehouse(pageNum, pageSize,kqmc));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "空仓报警(旧)", notes = "空仓报警(旧)")
    @GetMapping(value = "/selectEmptyWarehouseDetail")
    public RootResult<Object> selectEmptyWarehouseDetail(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                                   @RequestParam(value="kqbm",required = true) String kqbm,
                                                   @RequestParam(value="cfmc",required = false) String cfmc,
                                                   @RequestParam(value="hwmc",required = false) String hwmc) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(alarmService.selectEmptyWarehouseDetail(pageNum, pageSize,kqbm,cfmc,hwmc));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }
}
