package com.jusfoun.ydylsz.service;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.mapper.AlarmMapper;
import com.jusfoun.ydylsz.util.PageUtils;
import com.jusfoun.ydylsz.utils.StringUtils;
import com.jusfoun.ydylsz.vo.StorageOverrunVO;
import com.jusfoun.ydylsz.vo.WarehouseEmptyAlarmVO;
import com.jusfoun.ydylsz.vo.WarehouseOverdueAlarmVO;
import com.jusfoun.ydylsz.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class AlarmService {

    @Autowired
    private AlarmMapper alarmMapper;


    public PageUtils<Object> selectStorageOverrun(Integer pageNum, Integer pageSize,String kqmc,String type) {
        PageUtils<Object> pageInfo = new PageUtils<Object>();
        List<StorageOverrunVO> list = new ArrayList<>();
        if("1".equals(type)) {
            list = alarmMapper.selectStocksOverrun(kqmc);
        } else if("2".equals(type)) {
            list = alarmMapper.selectStorageOverrun(kqmc);
        }
        if(!list.isEmpty())  {
            List<Object> resList = new ArrayList<Object>();
            int startRow = pageNum * pageSize - pageSize;
            Map<String,List<StorageOverrunVO>> resultMap = list.stream().collect(Collectors.groupingBy(storageOverrunVO->storageOverrunVO.getKqmc()==null?"":storageOverrunVO.getKqmc()));
            resList =  resultMap.entrySet().stream()
                    .skip(startRow).limit(pageSize).collect(Collectors.toList());
            //填充数据
            pageInfo.setTotal(resultMap.size());
            pageInfo.setList(resList);
        }
        return pageInfo;
    }

    public PageInfo selectEmptyWarehouse(Integer pageNum, Integer pageSize, String kqmc) {
        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = alarmMapper.selectEmptyWarehouse(kqmc);
        return new PageInfo(list);
    }

    public PageInfo selectEmptyWarehouseDetail(Integer pageNum, Integer pageSize,String kqbm ,String cfmc,String hwmc) {
        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = alarmMapper.selectEmptyWarehouseDetail(kqbm,cfmc,hwmc);
        return new PageInfo(list);
    }


    public Object getEmptyWarehousePageList(Integer pageNum, Integer pageSize, Integer clzt,Integer clfs,Integer cfzt, String ccqy, String cfmc,String kqbm) {
        PageHelper.startPage(pageNum, pageSize);
        List<WarehouseEmptyAlarmVO> list = alarmMapper.selectEmptyWarehouseList(clzt,clfs,cfzt,ccqy,cfmc,kqbm);
        return new PageInfo(list);
    }

    public boolean dealEmptyWarehouseAlarm(WarehouseEmptyAlarmVO vo) {

        if(alarmMapper.dealEmptyWarehouseAlarm(vo) > 0){
            return true;
        }
        return false ;
    }

    /**
     * @Author feng.liu@ourwill.com.cn
     * @Description //空仓警告监测
     *
     * @return void
     **/
    public void surveyEmptyWarehouseAlarm(){

        //查寻出封仓的数据
        List<WarehouseEmptyAlarmVO> originList =  alarmMapper.selectOriginEmptyWarehouse();
        for(WarehouseEmptyAlarmVO vo:originList){
            vo.setId(UUID.randomUUID().toString());
            vo.setClzt(0);
            vo.setBjsj(new Date());

            Double cw = vo.getCw().doubleValue();
            Double pjlw = vo.getPjlw().doubleValue();
            if(cw > 0 && pjlw > 0){
                if(Math.abs(cw - pjlw) <= 5 ){
                    vo.setCfzt(1);//空仓
                    alarmMapper.insertWarehouseEmptyAlarm(vo);
                }else{
                    Integer floors = alarmMapper.selectWarehouseFloorsByLqId(vo.getLqid());
                    Double f = Math.ceil(floors / 2.0);
                    Integer countFloors = f.intValue();
                    if(countFloors != null && countFloors > 0){
                        Double upperLayerPjlw = alarmMapper.selectUpperLayerPjlw(vo.getLqid(),countFloors);
                        if(Math.abs(cw - upperLayerPjlw) <= 5 ){
                            vo.setCfzt(2);//半仓
                            alarmMapper.insertWarehouseEmptyAlarm(vo);
                        }
                    }

                }
            }
        }
    }

    public PageInfo getOverdueWarehousePageList(Integer pageNum, Integer pageSize, Integer clzt, String ccqy, String cfmc, String pzbm, Integer clfs,String kqbm) {

        PageHelper.startPage(pageNum, pageSize);
        List<WarehouseOverdueAlarmVO> list = alarmMapper.selectOverdueWarehouseList(clzt,ccqy,cfmc,pzbm,clfs,kqbm);
        return new PageInfo(list);
    }

    public boolean dealOverdueAlarm(WarehouseOverdueAlarmVO vo) {
        return alarmMapper.dealOverdueAlarm(vo) > 0 ?true:false ;
    }

    /**
     * @Author feng.liu@ourwill.com.cn
     * @Description //库存年限超期警告监测
     *
     * @return void
     **/
    public void surveyOverdueAlarm() throws ParseException {

        //查寻出封仓的数据
        List<WarehouseOverdueAlarmVO> originList =  alarmMapper.selectOverdueWarehouse();
        for(WarehouseOverdueAlarmVO vo:originList){
            int year = 0;
            int mouth = 0;
            if(!StringUtils.isEmpty(vo.getScnf()) && !StringUtils.isEmpty(vo.getCbnx())){

                if(vo.getCbnx().contains("年") && vo.getCbnx().contains("月")){
                    String[] str = vo.getCbnx().split("年");
                    if(str != null && str.length ==2){
                        if(!StringUtils.isEmpty(str[0].trim())){
                            year = Integer.parseInt(str[0].trim());
                        }
                        if(!StringUtils.isEmpty(str[1].trim())){
                            mouth = Integer.parseInt(str[1].replace("月","").trim());
                        }
                    }
                }else if(vo.getCbnx().contains("年")){
                    year = Integer.parseInt(vo.getCbnx().substring(0,vo.getCbnx().length()-1));
                }

                //根据生产年份获取到储存超限时间
                String scnfsjstr =  vo.getScnf();
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
                Date scnfsj = sdf.parse(scnfsjstr);
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(scnfsj);
                calendar.add(Calendar.YEAR, year+1);
                calendar.add(Calendar.MONTH, mouth);
                calendar.add(Calendar.DATE, -1);
                Date cccxsj = calendar.getTime();

                //计算出离储存超限时间3个月前时间
                Calendar cccxsjCalendar = Calendar.getInstance();
                cccxsjCalendar.setTime(cccxsj);
                cccxsjCalendar.add(Calendar.MONTH,-3);
                Date yjsj3 = cccxsjCalendar.getTime();

                //计算出离储存超限时间1个月前时间
                Calendar cccxsjCalendar1 = Calendar.getInstance();
                cccxsjCalendar1.setTime(cccxsj);
                cccxsjCalendar1.add(Calendar.MONTH,-1);
                Date yjsj1 = cccxsjCalendar1.getTime();

                Date now = new Date();
                /*SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy-MM-dd");
                Date now = sdf1.parse("2013-11-30");*/
                int cfzt = 0;
                //超周期
                if(cccxsj.getTime() <= now.getTime()){
                    cfzt = 3;
                }else if(now.getTime() >= yjsj3.getTime() && now.getTime() < yjsj1.getTime()){
                    //近3月
                    cfzt = 1;
                }else if( now.getTime() >= yjsj1.getTime() && now.getTime() < cccxsj.getTime()){
                    //近1月
                    cfzt = 2;
                }
                BigDecimal kcsl = vo.getKcsl()!=null?vo.getKcsl():new BigDecimal(0);
                if(kcsl.compareTo(new BigDecimal(0)) > 0  && cfzt > 0){
                    WarehouseOverdueAlarmVO vo1 = alarmMapper.selectOverdueWarehouseByParam(vo.getKqbm(),vo.getCfbm(),vo.getPzbm(),vo.getScnf(),cfzt,0);
                    if(vo1 == null){
                        vo.setBjsj(now);
                        vo.setClzt(0);
                        vo.setCccxsj(cccxsj);
                        vo.setCfzt(cfzt);
                        vo.setId(UUID.randomUUID().toString());
                        alarmMapper.insertWarehouseOverdueAlarm(vo);
                    }
                }
            }
        }
    }

    public void surveyDealOverdueAlarm() {
        //先查询出未处理的
        List<WarehouseOverdueAlarmVO> list = alarmMapper.selectOverdueWarehouseList(0, null, null, null, null,null);
        if (list != null && list.size() > 0) {
            for (WarehouseOverdueAlarmVO alarmVO : list) {
                WarehouseOverdueAlarmVO vo1 = alarmMapper.selectOverdueWarehouseByAlarm(alarmVO.getKqbm(), alarmVO.getCfbm(), alarmVO.getPzbm(), alarmVO.getScnf());
                if (vo1 != null) {
                    BigDecimal kcsl = vo1.getKcsl() != null ? vo1.getKcsl() : new BigDecimal(0);
                    if (kcsl.compareTo(new BigDecimal(0)) <= 0) {
                        alarmVO.setClfs(1);
                        alarmVO.setClrmc("自动");
                        alarmVO.setClzt(1);
                        alarmVO.setClyj("经系统检测，该报警内容已恢复正常");
                        alarmVO.setClsj(new Date());
                        alarmMapper.dealOverdueAlarm(alarmVO);
                    }
                }else{
                    alarmVO.setClfs(1);
                    alarmVO.setClrmc("自动");
                    alarmVO.setClzt(1);
                    alarmVO.setClyj("经系统检测，该报警内容已恢复正常");
                    alarmVO.setClsj(new Date());
                    alarmMapper.dealOverdueAlarm(alarmVO);
                }
            }

        }
    }
    public void storageBadTemperaturepoint() {
        List<StorageBadTemperaturePointVO> voList = alarmMapper.selectBadTemperaturepointList();
        List<StorageBadTemperaturePointDTO> allList = alarmMapper.selectBadTemperaturepoint();
        List<StorageBadTemperaturePointDTO> list = new ArrayList<>();
        if (voList.size() <= 0) {
            // 获取今天日期，yyyy-MM-dd格式
            String today = DateUtil.today();
            Date date = DateUtil.parse(today, "yyyy-MM-dd");
            if (allList.size() > 0) {
                // 过滤allList里面tTime时间大于等于date的集合
                list = allList.stream().filter(dto -> {
                    String tTime = dto.getTTime();
                    Date tDate = DateUtil.parse(tTime, "yyyy-MM-dd HH:mm:ss");
                    return tDate.getTime() >= date.getTime();
                }).collect(Collectors.toList());
                // 如果list还是为空，就取allList里面的大于第一个tTime的日期格式yyyy-MM-dd的集合
                if (list.size() <= 0) {
                    StorageBadTemperaturePointDTO dto = allList.get(0);
                    String tTime = dto.getTTime();
                    Date tDate = DateUtil.parse(tTime, "yyyy-MM-dd HH:mm:ss");
                    String format = DateUtil.format(tDate, "yyyy-MM-dd");
                    list = allList.stream().filter(dto1 -> {
                        String tTime1 = dto1.getTTime();
                        Date tDate1 = DateUtil.parse(tTime1, "yyyy-MM-dd HH:mm:ss");
                        return tDate1.getTime() >= DateUtil.parse(format, "yyyy-MM-dd").getTime();
                    }).collect(Collectors.toList());
                }
            }

        } else {
            StorageBadTemperaturePointVO storageBadTemperaturePointVO = voList.get(0);
            // 过滤allList里面tTime时间大于storageBadTemperaturePointVOl的updateTime的集合
            list = allList.stream().filter(dto -> {
                String tTime = dto.getTTime();
                Date tDate = DateUtil.parse(tTime, "yyyy-MM-dd HH:mm:ss");
                return tDate.getTime() > storageBadTemperaturePointVO.getUpdate_time().getTime();
            }).collect(Collectors.toList());

        }

        if (list.size() > 0) {
            for (StorageBadTemperaturePointDTO dto : list) {
                String tPoints = dto.getTPoints();
                if (!StringUtils.isEmpty(tPoints)) {
                    dto.setGzcwdsl(0);
                    JSONArray jsonArray = JSON.parseArray(dto.getTPoints());
                    if (jsonArray != null && jsonArray.size() > 0) {
                        for (int i = 0; i < jsonArray.size(); i++) {
                            JSONObject jsonObject = jsonArray.getJSONObject(i);
                            String temp = jsonObject.getString("temp");
                            if (!StringUtils.isEmpty(temp)) {
                                if (temp.contains("250")) {
                                    dto.setGzcwdsl(dto.getGzcwdsl() + 1);
                                }
                            }
                        }
                    }
                    if (dto.getGzcwdsl() > 0) {
                        StorageBadTemperaturePointVO vo = new StorageBadTemperaturePointVO();
                        vo.setId(UUID.randomUUID().toString().replace("-", ""));
                        vo.setKqbm(dto.getKqbm());
                        vo.setCfbm(dto.getCfbm());
                        vo.setCh(dto.getCh());
                        vo.setGzcwdsl(dto.getGzcwdsl());
                        vo.setBjsj(new Date());
                        vo.setCreate_time(new Date());
                        // dtoTtime设置为vo的updateTime
                        vo.setUpdate_time(DateUtil.parse(dto.getTTime(), "yyyy-MM-dd HH:mm:ss"));
                        String kqdm = alarmMapper.getKqdmForCameraMalfunctionByKqbm(vo.getKqbm());
                        if (!StringUtils.isEmpty(kqdm)) {
                            vo.setKqdm(kqdm);
                        }
                        alarmMapper.insertWarehouseBadTemperaturepoint(vo);
                    }
                }
            }
        }
    }

    public Map<String,Object> statisticAlarm() {
        return alarmMapper.statisticAlarm();
    }
}
