package com.jusfoun.ydylsz.service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.jusfoun.ydylsz.mapper.StorageDewingWarningMapper;
import com.jusfoun.ydylsz.vo.StorageDewingWarning;
import com.jusfoun.ydylsz.vo.TPointsObj;
import com.jusfoun.ydylsz.vo.TemperatureAndHumidityCheck;

import cn.hutool.core.lang.UUID;

@Service
public class StorageDewingWarningService {

	@Resource
	private StorageDewingWarningMapper storageDewingWarningMapper;
	
	private final static double WD_CZ=8;

	/**
	 * 查询温度报警数据集合
	 * @param kqmc 承储企业
	 * @param chmc 仓房名称
	 * @param jcsj 监测日期
	 * @param jblx 警报类型
	 * @return
	 */
	public List<StorageDewingWarning> getList(String kqmc, String chmc, String bjrq) throws Exception {
		StorageDewingWarning storageDewingWarning = new StorageDewingWarning();
		if (null != kqmc && !kqmc.isEmpty()) {
			storageDewingWarning.setKqmc(kqmc);
		}
		if (null != chmc && !chmc.isEmpty()) {
			storageDewingWarning.setChmc(chmc);
		}
		if (null != bjrq && !bjrq.isEmpty()) {
			storageDewingWarning.setBjsj_str(bjrq);
		}
		List<StorageDewingWarning> list = storageDewingWarningMapper.list(storageDewingWarning);
		return list;
	}

	/**
	 * 结露预警数据检测
	 */
	//@Scheduled(cron = "0 0 23 * * ?")
	public void getDewingWarning() {
		List<TemperatureAndHumidityCheck> list = storageDewingWarningMapper.getTTestDate();
		if (null != list && list.size() >0) {
			TemperatureAndHumidityCheck obj = null;
			List<TPointsObj> tP = null;
			if (null != list && list.size() > 0) {
				Map<String, BigDecimal> p_map = null;
				for (int i = 0; i < list.size(); i++) {
					obj = list.get(i);
					tP = JSON.parseArray(obj.getPoints(), TPointsObj.class);

					//把所有的点按照层列行的顺序为key，保存在新的Map中，方便后面获取取
					p_map = new HashMap<>();
					for (TPointsObj tpo : tP) {
						String key = tpo.getZ()+"-"+tpo.getX()+"-"+tpo.getY();
						key = key.trim();
						p_map.put(key, tpo.getTemp());
					}

					//检测这条数据有没有符合规则的数据
					dewingWarningCheck(obj, p_map);
				}

				
			}
		}
	}

	private void dewingWarningCheck(TemperatureAndHumidityCheck obj, Map<String, BigDecimal> p_map) {
		//重新遍历点位，计算验证规则
		String zb_key = "";//坐标点的key
		String []zb = null;//坐标
		int x;
		int y;
		int z;
		int n_x = 0;
		int n_y = 0;
		BigDecimal val = null;//原点位值
		String new_key = "";//新点位的key
		BigDecimal new_val = null;//新点位的value
		double abs_val = 0;//两个点位值的绝对值
		String param1 = "";
		String param2 = "";
		Iterator<String> it = p_map.keySet().iterator();
		while(it.hasNext()) {
			zb_key = it.next();
			zb = zb_key.split("-");
			//先取得当前点位(z, x, y)
			z = Integer.parseInt(zb[0]);
			x = Integer.parseInt(zb[1]);
			y = Integer.parseInt(zb[2]);
			val = p_map.get(zb_key);
			if (val.compareTo(new BigDecimal(250)) == 0) {
				continue;
			}
			param1 = z+"层-"+x+"-"+y;

			/* 取得前后左右的四个点(z, x+1, y),(z, x-1, y),(z, x, y+1),(z, x, y-1)，并计算  start */
			for (int i = 1; i < 5; i++) {
				if (i==1) {
					n_x = x+1;//右边点位
					new_key = z+"-"+n_x+"-"+y;
					new_val = p_map.get(new_key);
					if (null != new_val) {
						abs_val = new_val.subtract(val).abs().doubleValue();
						if (abs_val > WD_CZ) {
							param2 = z+"层-"+n_x+"-"+y;
							insertStorageDewingWarning(param1, param2, val, new_val, abs_val, obj);
						}
					}
					continue;
				}
				if (i==2) {
					n_x = x-1;//左边点位
					if (n_x == 0) continue;
					new_key = z+"-"+n_x+"-"+y;
					new_val = p_map.get(new_key);
					if (null != new_val) {
						abs_val = new_val.subtract(val).abs().doubleValue();
						if (abs_val > WD_CZ) {
							param2 = z+"层-"+n_x+"-"+y;
							insertStorageDewingWarning(param1, param2, val, new_val, abs_val, obj);
						}
					}
					continue;
				}
				if (i == 3) {
					n_y = y+1;//前边点位(z, x, y+1)
					new_key = z+"-"+x+"-"+n_y;
					new_val = p_map.get(new_key);
					if (null != new_val) {
						abs_val = new_val.subtract(val).abs().doubleValue();
						if (abs_val > WD_CZ) {
							param2 = z+"层-"+x+"-"+n_y;
							insertStorageDewingWarning(param1, param2, val, new_val, abs_val, obj);
						}
					}
					continue;
				}
				if (i == 4) {
					n_y = y-1;//后边点位(z, x, y-1)
					if (n_y == 0) continue;
					new_key = z+"-"+x+"-"+n_y;
					new_val = p_map.get(new_key);
					if (null != new_val) {
						abs_val = new_val.subtract(val).abs().doubleValue();
						if (abs_val > WD_CZ) {
							param2 = z+"层-"+x+"-"+n_y;
							insertStorageDewingWarning(param1, param2, val, new_val, abs_val, obj);
						}
					}
					continue;
				}
			}
			it.remove();//报过警的点以后不用比对了，所以要删除

			/* 取得前后左右的四个点(z, x+1, y),(z, x-1, y),(z, x, y+1),(z, x, y-1)，并计算  end */
			
		}
	}

	/**
	 * 保存报警数据
	 * @param param1 测温点
	 * @param param2 比对测温点
	 * @param val 检测点的温度值
	 * @param new_val 比对点的温度值
	 * @param abs_val 差值
	 * @param obj 原数据对象
	 */
	private void insertStorageDewingWarning(String param1, String param2, BigDecimal val, BigDecimal new_val, double abs_val, TemperatureAndHumidityCheck obj) {
		StorageDewingWarning storageDewingWarning = new StorageDewingWarning();
		storageDewingWarning.setId(UUID.randomUUID().toString().replace("-", ""));
		storageDewingWarning.setKqdm(obj.getKqdm());
		storageDewingWarning.setCh(obj.getCh());
		storageDewingWarning.setCwd(param1+","+param2);
		storageDewingWarning.setWd(val+","+new_val);
		storageDewingWarning.setWdc(new BigDecimal(abs_val));
		storageDewingWarning.setBjsj(obj.getJcsj());
		storageDewingWarning.setCreateTime(new Date());
		storageDewingWarning.setUpdateTime(storageDewingWarning.getCreateTime());
		storageDewingWarningMapper.insert(storageDewingWarning);
	}

}
