package com.jusfoun.ydylsz.service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import com.jusfoun.ydylsz.mapper.StorageHumidityWarningMapper;
import com.jusfoun.ydylsz.mapper.StorageTemperatureWarningMapper;
import com.jusfoun.ydylsz.vo.StorageHumidityWarning;
import com.jusfoun.ydylsz.vo.StorageTemperatureWarning;
import com.jusfoun.ydylsz.vo.TemperatureAndHumidityCheck;

import cn.hutool.core.lang.UUID;

@Service
public class StorageTemperatureWarningService {

	@Resource
	private StorageTemperatureWarningMapper storageTemperatureWarningMapper;
	
	@Resource
	private StorageHumidityWarningMapper storageHumidityWarningMapper;

	/**
	 * 查询温度报警数据集合
	 * @param kqmc 承储企业
	 * @param chmc 仓房名称
	 * @param jcsj 监测日期
	 * @param jblx 警报类型
	 * @return
	 */
	public List<StorageTemperatureWarning> getList(String kqmc, String chmc, String jcsj, String jblx) throws Exception {
		StorageTemperatureWarning storageTemperatureWarning = new StorageTemperatureWarning();
		if (null != kqmc && !kqmc.isEmpty()) {
			storageTemperatureWarning.setKqmc(kqmc);
		}
		if (null != chmc && !chmc.isEmpty()) {
			storageTemperatureWarning.setChmc(chmc);
		}
		if (null != jcsj && !jcsj.isEmpty()) {
			storageTemperatureWarning.setJcsj_str(jcsj);
		}
		if (null != jblx && !jblx.isEmpty()) {
			if ("1".equals(jblx)) {
				storageTemperatureWarning.setJblx("('1')");
			} else {
				storageTemperatureWarning.setJblx("('0','2')");
			}
		}
		List<StorageTemperatureWarning> list = storageTemperatureWarningMapper.list(storageTemperatureWarning);
		return list;
	}

	/**
	 * 检测测温数据，并根据预警设置，生成报警数据
	 */
	//@Scheduled(cron = "0 0 22 * * ?")
	public void getWdDetection() throws Exception {
		List<TemperatureAndHumidityCheck> list = storageTemperatureWarningMapper.getTTestDate();
		if (null != list && list.size() >0) {
			TemperatureAndHumidityCheck obj = null;
			BigDecimal wdyjgx = null;
			BigDecimal wdyjdx = null;
			for (int i = 0; i < list.size(); i++) {
				obj = list.get(i);

				//获取温度预警高限和低限值
				String[] yjz = obj.getWdyjyjz().split("-");
				wdyjdx = new BigDecimal(yjz[0]);
				wdyjgx = new BigDecimal(yjz[1]);

				/* 温度报警数据，优先保存报警数据，有报警数据后，预警数据就不要生成了 start */
				//仓高温大于温度报警高限
				if (obj.getCgw().compareTo(obj.getWdbjz()) > 0) {
					saveStorageTemperatureWarning(obj, "0");
				}
				//介于预警高限和报警高限之间，可以等于；生成粮温预警数据
				if (obj.getCgw().compareTo(wdyjgx) >= 0 && obj.getCgw().compareTo(obj.getWdbjz()) <= 0) {
					saveStorageTemperatureWarning(obj, "1");
				}
				//低于高温预警低限，可以等于；生成低温报警数据
				if (obj.getCdw().compareTo(wdyjdx) <= 0) {
					saveStorageTemperatureWarning(obj, "2");
				}
				/* 温度报警数据，优先保存报警数据，有报警数据后，预警数据就不要生成了 start */

				//生成湿度报警数据，规则：仓湿大于湿度报警高限
				if (obj.getCs().compareTo(obj.getSdbjz()) > 0) {
					saveStorageHumidityWarning(obj);
				}
			}
		}
	}

	private void saveStorageTemperatureWarning(TemperatureAndHumidityCheck obj, String bjlx) {
		StorageTemperatureWarning storageTemperatureWarning = new StorageTemperatureWarning();
		String uuid = UUID.randomUUID().toString().replace("-", "");
		storageTemperatureWarning.setId(uuid);
		storageTemperatureWarning.setKqdm(obj.getKqdm());
		storageTemperatureWarning.setCh(obj.getCh());
		storageTemperatureWarning.setCgw(obj.getCgw());
		storageTemperatureWarning.setCdw(obj.getCdw());
		storageTemperatureWarning.setCAvg(obj.getCavg());
		storageTemperatureWarning.setYjz(obj.getWdyjyjz());
		storageTemperatureWarning.setBjz(obj.getWdbjz());
		storageTemperatureWarning.setJcsj(obj.getJcsj());
		storageTemperatureWarning.setJblx(bjlx);
		storageTemperatureWarning.setCreateTime(new Date());
		storageTemperatureWarning.setUpdateTime(storageTemperatureWarning.getCreateTime());
		storageTemperatureWarningMapper.insert(storageTemperatureWarning);
	}

	private void saveStorageHumidityWarning(TemperatureAndHumidityCheck obj) {
		StorageHumidityWarning storageHumidityWarning = new StorageHumidityWarning();
		storageHumidityWarning.setId(UUID.randomUUID().toString().replace("-", ""));
		storageHumidityWarning.setKqdm(obj.getKqdm());
		storageHumidityWarning.setCh(obj.getCh());
		storageHumidityWarning.setCs(obj.getCs());
		storageHumidityWarning.setBjz(obj.getSdbjz());
		storageHumidityWarning.setBjsj(obj.getJcsj());
		storageHumidityWarning.setCreateTime(new Date());
		storageHumidityWarning.setUpdateTime(storageHumidityWarning.getCreateTime());
		storageHumidityWarningMapper.insert(storageHumidityWarning);
	}

}
