package com.jusfoun.ydylsz.service;

import java.lang.reflect.InvocationTargetException;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

import com.jusfoun.ydylsz.constants.RedisDataBaseIndex;
import com.jusfoun.ydylsz.constants.RedisKey;
import com.jusfoun.ydylsz.util.RedisUtil;
import com.jusfoun.ydylsz.vo.*;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.mapper.TemperatureMapper;
import com.unis.common.utils.CurrentUtil;

import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import redis.clients.jedis.Jedis;

@Service
public class TemperatureService {

	@Value("${depot.url}")
	private String depotUrl;

    @Value("#{'${org.shi-liu-qu}'.split(',')}")
    private List<String> city6District;
    @Value("#{'${org.all-data}'.split(',')}")
    private List<String> allDataOrg;

	@Autowired
	private TemperatureMapper temperatureMapper;

    public String getOrgAreaCode() {
        return temperatureMapper.getOrgAreaCode(CurrentUtil.getUserId());
    }

	public List<TemperatureVO> list(String cfbm) {
		return temperatureMapper.list(cfbm);
	}

	public List<TemperatureVO> chat(String cfbm) {
		List<String> data = new ArrayList<>();
		for (int i = 0; i < 54; i++) {
			if (StringUtils.isNotEmpty(getFirstDayOfWeek(i))) {
				data.add(getFirstDayOfWeek(i));
			}
		}
		TemperatureVO temperatureVO = new TemperatureVO();
		temperatureVO.setHwbm(cfbm);
		temperatureVO.setDate(data);
		List<TemperatureVO> temperatureVOs2 = new ArrayList<>();
		List<TemperatureVO> temperatureVOs = temperatureMapper.chat(temperatureVO);
		for (String string : data) {
			boolean is = false;
			for (TemperatureVO temperatureVO2 : temperatureVOs) {
				if (temperatureVO2.getTTime().equals(string)) {
					is = true;
					temperatureVOs2.add(temperatureVO2);
				}
				/*String a = temperatureVO2.getOuttemp();
				String c = temperatureVO2.getIntemp();
				String b = "100.00";
				int i = a.compareTo(b);
				int j = a.compareTo(c);
				if(i>0){
                    temperatureVO2.setOuttemp(temperatureVO2.getTAvg());
				}
				if(j>0){
					temperatureVO2.setIntemp(temperatureVO2.getTAvg());
				}*/
			}
			if (!is) {
				TemperatureVO temperatureVO2 = new TemperatureVO();
				temperatureVO2.setTTime(string);
				temperatureVO2.setInh("0");
				temperatureVO2.setIntemp("0");
				temperatureVO2.setOuttemp("0");
				temperatureVO2.setOuth("0");
				temperatureVO2.setTAvg("0");
				temperatureVO2.setTMax("0");
				temperatureVO2.setTMin("0");
				temperatureVOs2.add(temperatureVO2);
			}
		}
		return temperatureVOs2;
	}

	public static String getFirstDayOfWeek(int week) {
		Calendar cal = Calendar.getInstance();

		int year = cal.get(Calendar.YEAR);
		// 设置年份
		cal.set(Calendar.YEAR, year);
		// 设置周
		cal.set(Calendar.WEEK_OF_YEAR, week);
		// 设置该周第一天为星期一
		cal.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);
		// 格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		String firstDayOfWeek = sdf.format(cal.getTime());
		if (firstDayOfWeek.contains(String.valueOf(year)) && (cal.getTime().getTime() <= new Date().getTime())) {
			return firstDayOfWeek;
		}
		return null;
	}


	@Value("${config.url}")
	private String configUrl;

	public TemperatureVO cslwData(String id,String hwbm) {

		List<Map<String, Object>> mapDate = new ArrayList<>();
		TemperatureVO temperatureVO = temperatureMapper.select(id);
		List<String> bgy = temperatureMapper.getBgy(hwbm);
		temperatureVO.setBgy(bgy);
		if (temperatureVO == null) {
			return null;
		}
		String points = temperatureVO.getTPoints();
		JSONArray array = JSONUtil.parseArray(points);
		List<XYZVO> list = new ArrayList<XYZVO>();
		Set<String> set = new HashSet<String>();
		for (int i = 0; i < array.size(); i++) {
			JSONObject jsonObject = array.getJSONObject(i);
			XYZVO xyzvo = new XYZVO();
			xyzvo.setWeather(jsonObject.getStr("temp"));
			xyzvo.setX(jsonObject.getStr("x"));
			xyzvo.setY(jsonObject.getStr("y"));
			xyzvo.setZ(jsonObject.getStr("z"));
			list.add(xyzvo);
			set.add(jsonObject.getStr("z"));
		}
		DecimalFormat decimalFormat = new DecimalFormat(".00");
		if (set.size() <= 0) {
			return temperatureVO;
		}
		for (String string : set) {
			int i = 0;
			float big = 0, small = -100, total = 0;
			for (XYZVO xyzvo : list) {
				if (xyzvo.getZ().equals(string)) {
					if(Float.valueOf(xyzvo.getWeather())!=250.0){
						i++;
						total += Float.valueOf(xyzvo.getWeather());
						if (Float.valueOf(xyzvo.getWeather()) >= big) {
							big = Float.valueOf(xyzvo.getWeather());
						}
						if (Float.valueOf(xyzvo.getWeather()) <= small || small < -90) {
							small = Float.valueOf(xyzvo.getWeather());
						}
					}
				}
			}
			Map<String, Object> map = new HashMap<String, Object>();
			map.put("name", "第" + string + "层");
			map.put("value", "层高温：" + big + "℃，层低温：" + small + "℃，层均温：" + decimalFormat.format(total / i) + "℃");
			mapDate.add(map);
		}
		temperatureVO.setLwjh(mapDate);
		return temperatureVO;
	}

	public TemperatureVO mclwData(String id, String ch) {



		Double max = 30.0,min=3.0,cen=25.0;
		try {
			String result = HttpRequest.get(configUrl +"/1052").timeout(10000).execute().body();
			cn.hutool.json.JSONObject jsonObject5 = JSONUtil.parseObj(result);
			System.out.println(result);
			if(jsonObject5.getInt("infoCode")==200) {
				cn.hutool.json.JSONArray array = jsonObject5.getJSONArray("data");
				if(array!=null) {
					for(int i=0;i<array.size();i++) {
						cn.hutool.json.JSONObject jsonObject2 = array.getJSONObject(i);
						if(jsonObject2.getStr("configCode").equals("10520001")) {
							max = Double.valueOf(jsonObject2.getStr("configValue"));
						} else if(jsonObject2.getStr("configCode").equals("10520002")) {
							cen = Double.valueOf(jsonObject2.getStr("configValue"));
						} else if(jsonObject2.getStr("configCode").equals("10520003")) {
							min = Double.valueOf(jsonObject2.getStr("configValue"));
						}
					}
				}
			}
		} catch (Exception e) {
			System.out.println("超时了！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！");
		}

		List<List<Map<String, Object>>> mapDate = new ArrayList<List<Map<String, Object>>>();
		TemperatureVO temperatureVO = temperatureMapper.select(id);
		if (temperatureVO == null) {
			return null;
		}
		Set<String> sets = new HashSet<>();
		JSONArray array = JSONUtil.parseArray(temperatureVO.getTPoints());
		List<XYZVO> list = new ArrayList<>();
		for (int i = 0; i < array.size(); i++) {
			JSONObject jsonObject = array.getJSONObject(i);
			XYZVO xyzvo = new XYZVO();
			xyzvo.setWeather(jsonObject.getStr("temp"));
			xyzvo.setX(jsonObject.getStr("x"));
			xyzvo.setY(jsonObject.getStr("y"));
			xyzvo.setZ(jsonObject.getStr("z"));
			sets.add(jsonObject.getStr("y"));
			list.add(xyzvo);
		}

		TemperatureVO temperatureVO2 = temperatureMapper.selectVo(temperatureVO);
		if (temperatureVO2 == null) {
			for (String string : sets) {
				List<Map<String, Object>> maps = new ArrayList<>();
				for (XYZVO xyzvo : list) {
					if (xyzvo.getZ().equals(ch) && xyzvo.getY().equals(string)) {
						Map<String, Object> map = new HashMap<>();
						map.put("num", xyzvo.getWeather());
						if(Float.valueOf(xyzvo.getWeather())>max) {
							map.put("ys", "red");
						} else if (Float.valueOf(xyzvo.getWeather())<=max&&Float.valueOf(xyzvo.getWeather())>cen) {
							map.put("ys", "yellow");
						} else if (Float.valueOf(xyzvo.getWeather())<min) {
							map.put("ys", "blue");
						} else {
							map.put("ys", null);
						}
						map.put("fx", null);
						maps.add(map);
					}
				}
				mapDate.add(maps);
			}
			temperatureVO.setLwcjh(mapDate);
			return temperatureVO;

		}

		JSONArray array2 = JSONUtil.parseArray(temperatureVO2.getTPoints());
		List<XYZVO> list2 = new ArrayList<>();
		for (int i = 0; i < array2.size(); i++) {
			JSONObject jsonObject = array2.getJSONObject(i);
			XYZVO xyzvo = new XYZVO();
			xyzvo.setWeather(jsonObject.getStr("temp"));
			xyzvo.setX(jsonObject.getStr("x"));
			xyzvo.setY(jsonObject.getStr("y"));
			xyzvo.setZ(jsonObject.getStr("z"));
			list2.add(xyzvo);
		}
		for (String string : sets) {
			List<Map<String, Object>> maps = new ArrayList<>();
			for (XYZVO xyzvo : list) {
				if (xyzvo.getZ().equals(ch) && xyzvo.getY().equals(string)) {
					XYZVO xyzvo3 = null;
					for (XYZVO xyzvo2 : list2) {
						if (xyzvo.getX().equals(xyzvo2.getX()) && xyzvo.getY().equals(xyzvo2.getY())
								&& xyzvo.getZ().equals(xyzvo2.getZ())) {
							xyzvo3 = new XYZVO();
							xyzvo3 = xyzvo2;
						}
					}
					Map<String, Object> map = new HashMap<>();
					if (xyzvo3 == null) {
						map.put("num", xyzvo.getWeather());
						if(Float.valueOf(xyzvo.getWeather())>max) {
							map.put("ys", "red");
						} else if (Float.valueOf(xyzvo.getWeather())<=max&&Float.valueOf(xyzvo.getWeather())>cen) {
							map.put("ys", "yellow");
						} else if (Float.valueOf(xyzvo.getWeather())<min) {
							map.put("ys", "blue");
						} else {
							map.put("ys", null);
						}
						map.put("fx", null);
						maps.add(map);
					} else {
						if (Float.valueOf(xyzvo.getWeather()) > Float.valueOf(xyzvo3.getWeather())) {
							map.put("num", xyzvo.getWeather());
							if(Float.valueOf(xyzvo.getWeather())>max) {
								map.put("ys", "red");
							} else if (Float.valueOf(xyzvo.getWeather())<=max&&Float.valueOf(xyzvo.getWeather())>cen) {
								map.put("ys", "yellow");
							} else if (Float.valueOf(xyzvo.getWeather())<min) {
								map.put("ys", "blue");
							} else {
								map.put("ys", null);
							}
							map.put("fx", "PgUp");
							maps.add(map);
						} else if (Float.valueOf(xyzvo.getWeather()) < Float.valueOf(xyzvo3.getWeather())) {
							map.put("num", xyzvo.getWeather());
							if(Float.valueOf(xyzvo.getWeather())>max) {
								map.put("ys", "red");
							} else if (Float.valueOf(xyzvo.getWeather())<=max&&Float.valueOf(xyzvo.getWeather())>cen) {
								map.put("ys", "yellow");
							} else if (Float.valueOf(xyzvo.getWeather())<min) {
								map.put("ys", "blue");
							} else {
								map.put("ys", null);
							}
							map.put("fx", "PgDn");
							maps.add(map);
						} else {
							map.put("num", xyzvo.getWeather());
							if(Float.valueOf(xyzvo.getWeather())>max) {
								map.put("ys", "red");
							} else if (Float.valueOf(xyzvo.getWeather())<=max&&Float.valueOf(xyzvo.getWeather())>cen) {
								map.put("ys", "yellow");
							} else if (Float.valueOf(xyzvo.getWeather())<min) {
								map.put("ys", "blue");
							} else {
								map.put("ys", null);
							}
							map.put("fx", null);
							maps.add(map);
						}
					}
				}
			}

			mapDate.add(maps);

		}

		temperatureVO.setLwcjh(mapDate);
		return temperatureVO;
	}

	public List<TemperatureVO> listAll(String cfbm) {
		List<TemperatureVO> temperatureVOs22222 = temperatureMapper.list(cfbm);
		for(TemperatureVO temperatureVO : temperatureVOs22222) {

			List<Map<String, Object>> mapDate = new ArrayList<>();
			String points = temperatureVO.getTPoints();
			JSONArray array = JSONUtil.parseArray(points);
			List<XYZVO> list = new ArrayList<>();
			Set<String> set = new HashSet<>();
			XYZVO minObject = new XYZVO();
			XYZVO maxObject = new XYZVO();
			for (int i = 0; i < array.size(); i++) {
				JSONObject jsonObject = array.getJSONObject(i);
				XYZVO xyzvo = new XYZVO();
				xyzvo.setWeather(jsonObject.getStr("temp"));
				xyzvo.setX(jsonObject.getStr("x"));
				xyzvo.setY(jsonObject.getStr("y"));
				xyzvo.setZ(jsonObject.getStr("z"));
				list.add(xyzvo);
				set.add(jsonObject.getStr("z"));
				if(i!=0) {
					if(Float.valueOf(xyzvo.getWeather())>Float.valueOf(maxObject.getWeather())) {
						maxObject = xyzvo;
					}
					if(Float.valueOf(xyzvo.getWeather())<Float.valueOf(minObject.getWeather())) {
						minObject =xyzvo;
					}
				} else {
					minObject =xyzvo;
					maxObject = xyzvo;
				}
			}
			temperatureVO.setTMax(maxObject.getWeather());
			temperatureVO.setTMin(minObject.getWeather());
			temperatureVO.setTMaxName(maxObject.getZ() + "层-"+maxObject.getX()+"-"+maxObject.getY());
			temperatureVO.setTMinName(minObject.getZ() + "层-"+minObject.getX()+"-"+minObject.getY());
			DecimalFormat decimalFormat = new DecimalFormat(".00");
			for (String string : set) {
				int i = 0;
				float big = 0, small = -100, total = 0;
				for (XYZVO xyzvo : list) {
					if (xyzvo.getZ().equals(string)) {
						i++;
						total += Float.valueOf(xyzvo.getWeather());
						if (Float.valueOf(xyzvo.getWeather()) >= big) {
							big = Float.valueOf(xyzvo.getWeather());
						}
						if (Float.valueOf(xyzvo.getWeather()) <= small || small < -90) {
							small = Float.valueOf(xyzvo.getWeather());
						}
					}
				}
				Map<String, Object> map = new HashMap<String, Object>();
				map.put("name", string + "层-1-1");
				map.put("value", decimalFormat.format(total / i) + "℃");
				mapDate.add(map);
			}
			temperatureVO.setLwjh(mapDate);
		}
		return temperatureVOs22222;
	}

	public PageInfo<TemperatureVO> page(String cfbm, Integer pageNo, Integer pageSize) {
		PageHelper.startPage(pageNo, pageSize);
		List<TemperatureVO> temperatureVOs22222 = temperatureMapper.list(cfbm);
		for(TemperatureVO temperatureVO : temperatureVOs22222) {
			List<Map<String, Object>> mapDate = new ArrayList<>();
			String points = temperatureVO.getTPoints();
			JSONArray array = JSONUtil.parseArray(points);
			List<XYZVO> list = new ArrayList<>();
			Set<String> set = new HashSet<>();
			XYZVO minObject = new XYZVO();
			XYZVO maxObject = new XYZVO();
			for (int i = 0; i < array.size(); i++) {
				JSONObject jsonObject = array.getJSONObject(i);
				XYZVO xyzvo = new XYZVO();
				xyzvo.setWeather(jsonObject.getStr("temp"));
				xyzvo.setX(jsonObject.getStr("x"));
				xyzvo.setY(jsonObject.getStr("y"));
				xyzvo.setZ(jsonObject.getStr("z"));
				list.add(xyzvo);
				set.add(jsonObject.getStr("z"));
				if(i!=0) {
					if(Float.valueOf(xyzvo.getWeather())>Float.valueOf(maxObject.getWeather())) {
						maxObject = xyzvo;
					}
					if(Float.valueOf(xyzvo.getWeather())<Float.valueOf(minObject.getWeather())) {
						minObject =xyzvo;
					}
				} else {
					minObject =xyzvo;
					maxObject = xyzvo;
				}
			}
			temperatureVO.setTMax(maxObject.getWeather());
			temperatureVO.setTMin(minObject.getWeather());
			temperatureVO.setTMaxName(maxObject.getZ() + "层-"+maxObject.getX()+"-"+maxObject.getY());
			temperatureVO.setTMinName(minObject.getZ() + "层-"+minObject.getX()+"-"+minObject.getY());
			DecimalFormat decimalFormat = new DecimalFormat(".00");
			for (String string : set) {
				int i = 0;
				float big = 0, small = -100, total = 0;
				for (XYZVO xyzvo : list) {
					if (xyzvo.getZ().equals(string)) {
						i++;
						total += Float.parseFloat(xyzvo.getWeather());
						if (Float.parseFloat(xyzvo.getWeather()) >= big) {
							big = Float.parseFloat(xyzvo.getWeather());
						}
						if (Float.parseFloat(xyzvo.getWeather()) <= small || small < -90) {
							small = Float.parseFloat(xyzvo.getWeather());
						}
					}
				}
				Map<String, Object> map = new HashMap<>();
				map.put("name", string + "层-1-1");
				map.put("value", decimalFormat.format(total / i) + "℃");
				mapDate.add(map);
			}
			temperatureVO.setLwjh(mapDate);

			// 机动点信息
			String id = temperatureVO.getId();
			List<TemperatureJJDVO> jddInfoList = temperatureMapper.getJddInfoList(temperatureVO.getOrgId(),temperatureVO.getId());
			if(!jddInfoList.isEmpty() && jddInfoList.get(0) != null) {
				try {
					BeanUtils.copyProperties(temperatureVO,jddInfoList.get(0));
				} catch (IllegalAccessException | InvocationTargetException e) {
					e.printStackTrace();
				}
            }

		}

		if(!temperatureVOs22222.isEmpty()) {
			ThresholdVO thresholdVO = temperatureMapper.getThreshold(temperatureVOs22222.get(0).getOrgId(),temperatureVOs22222.get(0).getStorehouseCode());
			temperatureVOs22222.get(0).setThreshold(thresholdVO);
		}
		return new PageInfo<>(temperatureVOs22222);
	}
	public List<TemperatureVO> listnew(String cfbm) {
		return temperatureMapper.listnew(cfbm);
	}

    public List<BadTemperaturePointDTO> badTemperature(String roleId) {
        // todo
        Map<String, Object> params = new HashMap<>();
        String orgId = CurrentUtil.getOrgId();
        params.put("orgId", orgId);
        Jedis jedis = RedisUtil.getJedis(RedisDataBaseIndex.DB2);
        String s = jedis.get(RedisKey.ORG_RELATE + orgId);
        com.alibaba.fastjson.JSONObject data = com.alibaba.fastjson.JSONObject.parseObject(s, com.alibaba.fastjson.JSONObject.class);

        if (data != null) {
            String type = data.getString("type");
            params.put("type", type);
            com.alibaba.fastjson.JSONArray orgList = data.getJSONArray("orgList");
            Optional.ofNullable(orgList).ifPresent(i-> {
                params.put("orgList", i.toJavaList(String.class));
            });
        }else {
            params.put("type", null);
        }

        List<TemperatureVO> temperatureLatestList = temperatureMapper.listLatestTemperature(params);

        List<TemperatureVO> temperatureVOList = temperatureLatestList.stream()
                .peek(item -> {
                    List<TPointsObj> tPointsObjs1 = new JSONArray(item.getTPoints()).toList(TPointsObj.class);
                    System.out.println(tPointsObjs1.size());
                    List<TPointsObj> tPointsObjs = tPointsObjs1.stream()
                            .filter(TPointsObj::isBad)
                            .collect(Collectors.toList());
                    item.setTPointsObjList(tPointsObjs);
                })
                .filter(TemperatureVO::isPointNotEmpty)
                .collect(Collectors.toList());
        LinkedHashMap<String, List<TemperatureVO>> temperatureMap = temperatureVOList.stream()
                .collect(Collectors.groupingBy(i -> i.getDepotName() + "@" + i.getOrgId(), LinkedHashMap::new, Collectors.toList()));
        return temperatureMap.entrySet().stream().map(item -> {
            String key = item.getKey();
            String[] keys = key.split("@");
            long count = item.getValue().size();
            return BadTemperaturePointDTO.builder().orgId(keys[1]).pointNum(count).name(keys[0]).build();
        }).collect(Collectors.toList());
    }

	public List<BadTempVO> badCamera() {
		List<BadTemp> list = temperatureMapper.badCamera();
		List<BadTempVO> result = new ArrayList<>();
		Map<String,List<BadTemp>> map = new HashMap<>();
		for(BadTemp badTemp:list){
			if(map.get(badTemp.getDwmc())!=null){
				map.get(badTemp.getDwmc()).add(badTemp);
			}else{
				List<BadTemp> news = new ArrayList<>();
				news.add(badTemp);
				map.put(badTemp.getDwmc(),news);
			}
		}
		//查询最新的温度id和我方仓房编号
		for (Map.Entry<String,List<BadTemp>> m : map.entrySet()) {
			BadTempVO badTempVO = new BadTempVO();
			badTempVO.setName(m.getKey());
			badTempVO.setBadTemps(m.getValue());
			result.add(badTempVO);
		}
		return result;
	}

    public JSONObject pageBadTemperatureByOrg(int pageNum, int pageSize, String orgId) {
        List<TemperatureVO> allLatestData = temperatureMapper.listAllTemperatureByOrg(orgId);
        List<String> badPointIdList = allLatestData.stream().filter(TemperatureVO::isBadPoint).map(TemperatureVO::getId).collect(Collectors.toList());
        List<TemperatureVO> list2 = temperatureMapper.pageBadTemperatureByOrg(orgId, false, badPointIdList);
        long count = list2.stream().flatMap(item -> new JSONArray(item.getTPoints())
                .toList(TPointsObj.class).stream()
                .filter(TPointsObj::isBad)).count();
        PageHelper.startPage(pageNum, pageSize);
        List<TemperatureVO> list = temperatureMapper.pageBadTemperatureByOrg(orgId, true, badPointIdList);
        list.forEach(i -> {
            List<TPointsObj> tPointsObjList = new JSONArray(i.getTPoints()).toList(TPointsObj.class)
                    .stream()
                    .filter(TPointsObj::isBad)
                    .collect(Collectors.toList());
            i.setTPointsObjList(tPointsObjList);
            i.setTPoints(null);
        });
        PageInfo<TemperatureVO> pageInfo = new PageInfo<>(list);
        pageInfo.setPageNum(pageNum);
        pageInfo.setPageSize(pageSize);
        JSONObject jsonObject = new JSONObject(pageInfo);
        jsonObject.putOpt("badPointTotal", count);
        return jsonObject;
    }

	public PageInfo<StorageBadTemperaturePointDTO> storageBadTemperaturepoint(Integer pageNo, Integer pageSize ,String kqmc , String bjsj,String kqdm) {
		Map<String, Object> params = new HashMap<>();
		String orgId = CurrentUtil.getOrgId();
		boolean isCity6 = city6District.contains(orgId);
		boolean isAllDataOrg = allDataOrg.contains(orgId);
		if (isCity6) {
			params.put("isCity6", true);
		}else if (isAllDataOrg) {
			params.put("isAllDataOrg", true);
		}else {
			params.put("orgCode", orgId);
			String areaCode = getOrgAreaCode();
			params.put("areaCode", areaCode);
		}
		if (StringUtils.isNotEmpty(kqmc)) {
			params.put("kqmc", kqmc);
		}
		params.put("orgId", orgId);
		if (StringUtils.isNotEmpty(bjsj)) {
			params.put("bjsj", bjsj);
		}
		if (StringUtils.isNotEmpty(kqdm)) {
			params.put("kqdm", kqdm);
		}
		List<StorageBadTemperaturePointDTO> list = temperatureMapper.storageBadTemperaturepoint(params);

		return new PageInfo<StorageBadTemperaturePointDTO>(list);
	}

}
